@@ -25,7 +25,6 @@ from typing import TYPE_CHECKING, Any, Generic, Optional, Tuple, Union, cast, ov
 try:
     import pytz
     from apscheduler.executors.asyncio import AsyncIOExecutor
-    from apscheduler.job import Job as APSJob
     from apscheduler.schedulers.asyncio import AsyncIOScheduler
 
     APS_AVAILABLE = True
@@ -38,9 +37,15 @@ from telegram.ext._extbot import ExtBot
 from telegram.ext._utils.types import CCT, JobCallback
 
 if TYPE_CHECKING:
+    if APS_AVAILABLE:
+        from apscheduler.job import Job as APSJob
+
     from telegram.ext import Application
 
 
+_ALL_DAYS = tuple(range(7))
+
+
 class JobQueue(Generic[CCT]):
     """This class allows you to periodically perform tasks with the bot. It is a convenience
     wrapper for the APScheduler library.
@@ -55,17 +60,17 @@ class JobQueue(Generic[CCT]):
 
         .. code-block:: bash
 
-           pip install python-telegram-bot[job-queue]
+           pip install "python-telegram-bot[job-queue]"
 
     Examples:
         :any:`Timer Bot <examples.timerbot>`
 
     .. seealso:: :wiki:`Architecture Overview <Architecture>`,
-        :wiki:`Job Queue <Extensions-%E2%80%93-JobQueue>`
+        :wiki:`Job Queue <Extensions---JobQueue>`
 
     .. versionchanged:: 20.0
         To use this class, PTB must be installed via
-        ``pip install python-telegram-bot[job-queue]``.
+        ``pip install "python-telegram-bot[job-queue]"``.
 
     Attributes:
         scheduler (:class:`apscheduler.schedulers.asyncio.AsyncIOScheduler`): The scheduler.
@@ -83,7 +88,7 @@ class JobQueue(Generic[CCT]):
         if not APS_AVAILABLE:
             raise RuntimeError(
                 "To use `JobQueue`, PTB must be installed via `pip install "
-                "python-telegram-bot[job-queue]`."
+                '"python-telegram-bot[job-queue]"`.'
             )
 
         self._application: "Optional[weakref.ReferenceType[Application]]" = None
@@ -155,15 +160,39 @@ class JobQueue(Generic[CCT]):
             return application
         raise RuntimeError("The application instance is no longer alive.")
 
+    @staticmethod
+    async def job_callback(job_queue: "JobQueue[CCT]", job: "Job[CCT]") -> None:
+        """This method is used as a callback for the APScheduler jobs.
+
+        More precisely, the ``func`` argument of :class:`apscheduler.job.Job` is set to this method
+        and the ``arg`` argument (representing positional arguments to ``func``) is set to a tuple
+        containing the :class:`JobQueue` itself and the :class:`~telegram.ext.Job` instance.
+
+        Tip:
+            This method is a static method rather than a bound method. This makes the arguments
+            more transparent and allows for easier handling of PTBs integration of APScheduler
+            when utilizing advanced features of APScheduler.
+
+        Hint:
+            This method is effectively a wrapper for :meth:`telegram.ext.Job.run`.
+
+        .. versionadded:: 20.4
+
+        Args:
+            job_queue (:class:`JobQueue`): The job queue that created the job.
+            job (:class:`~telegram.ext.Job`): The job to run.
+        """
+        await job.run(job_queue.application)
+
     def run_once(
         self,
         callback: JobCallback[CCT],
         when: Union[float, datetime.timedelta, datetime.datetime, datetime.time],
-        data: object = None,
-        name: str = None,
-        chat_id: int = None,
-        user_id: int = None,
-        job_kwargs: JSONDict = None,
+        data: Optional[object] = None,
+        name: Optional[str] = None,
+        chat_id: Optional[int] = None,
+        user_id: Optional[int] = None,
+        job_kwargs: Optional[JSONDict] = None,
     ) -> "Job[CCT]":
         """Creates a new :class:`Job` instance that runs once and adds it to the queue.
 
@@ -227,11 +256,11 @@ class JobQueue(Generic[CCT]):
         date_time = self._parse_time_input(when, shift_day=True)
 
         j = self.scheduler.add_job(
-            job.run,
+            self.job_callback,
             name=name,
             trigger="date",
             run_date=date_time,
-            args=(self.application,),
+            args=(self, job),
             timezone=date_time.tzinfo or self.scheduler.timezone,
             **job_kwargs,
         )
@@ -243,13 +272,13 @@ class JobQueue(Generic[CCT]):
         self,
         callback: JobCallback[CCT],
         interval: Union[float, datetime.timedelta],
-        first: Union[float, datetime.timedelta, datetime.datetime, datetime.time] = None,
-        last: Union[float, datetime.timedelta, datetime.datetime, datetime.time] = None,
-        data: object = None,
-        name: str = None,
-        chat_id: int = None,
-        user_id: int = None,
-        job_kwargs: JSONDict = None,
+        first: Optional[Union[float, datetime.timedelta, datetime.datetime, datetime.time]] = None,
+        last: Optional[Union[float, datetime.timedelta, datetime.datetime, datetime.time]] = None,
+        data: Optional[object] = None,
+        name: Optional[str] = None,
+        chat_id: Optional[int] = None,
+        user_id: Optional[int] = None,
+        job_kwargs: Optional[JSONDict] = None,
     ) -> "Job[CCT]":
         """Creates a new :class:`Job` instance that runs at specified intervals and adds it to the
         queue.
@@ -288,6 +317,18 @@ class JobQueue(Generic[CCT]):
                   :attr:`telegram.ext.Defaults.tzinfo` is used.
 
                 Defaults to :paramref:`interval`
+
+                Note:
+                    Setting :paramref:`first` to ``0``, ``datetime.datetime.now()`` or another
+                    value that indicates that the job should run immediately will not work due
+                    to how the APScheduler library works. If you want to run a job immediately,
+                    we recommend to use an approach along the lines of::
+
+                        job = context.job_queue.run_repeating(callback, interval=5)
+                        await job.run(context.application)
+
+                    .. seealso:: :meth:`telegram.ext.Job.run`
+
             last (:obj:`int` | :obj:`float` | :obj:`datetime.timedelta` |                        \
                    :obj:`datetime.datetime` | :obj:`datetime.time`, optional):
                 Latest possible time for the job to run. This parameter will be interpreted
@@ -341,9 +382,9 @@ class JobQueue(Generic[CCT]):
             interval = interval.total_seconds()
 
         j = self.scheduler.add_job(
-            job.run,
+            self.job_callback,
             trigger="interval",
-            args=(self.application,),
+            args=(self, job),
             start_date=dt_first,
             end_date=dt_last,
             seconds=interval,
@@ -359,11 +400,11 @@ class JobQueue(Generic[CCT]):
         callback: JobCallback[CCT],
         when: datetime.time,
         day: int,
-        data: object = None,
-        name: str = None,
-        chat_id: int = None,
-        user_id: int = None,
-        job_kwargs: JSONDict = None,
+        data: Optional[object] = None,
+        name: Optional[str] = None,
+        chat_id: Optional[int] = None,
+        user_id: Optional[int] = None,
+        job_kwargs: Optional[JSONDict] = None,
     ) -> "Job[CCT]":
         """Creates a new :class:`Job` that runs on a monthly basis and adds it to the queue.
 
@@ -418,9 +459,9 @@ class JobQueue(Generic[CCT]):
         job = Job(callback=callback, data=data, name=name, chat_id=chat_id, user_id=user_id)
 
         j = self.scheduler.add_job(
-            job.run,
+            self.job_callback,
             trigger="cron",
-            args=(self.application,),
+            args=(self, job),
             name=name,
             day="last" if day == -1 else day,
             hour=when.hour,
@@ -436,12 +477,12 @@ class JobQueue(Generic[CCT]):
         self,
         callback: JobCallback[CCT],
         time: datetime.time,
-        days: Tuple[int, ...] = tuple(range(7)),
-        data: object = None,
-        name: str = None,
-        chat_id: int = None,
-        user_id: int = None,
-        job_kwargs: JSONDict = None,
+        days: Tuple[int, ...] = _ALL_DAYS,
+        data: Optional[object] = None,
+        name: Optional[str] = None,
+        chat_id: Optional[int] = None,
+        user_id: Optional[int] = None,
+        job_kwargs: Optional[JSONDict] = None,
     ) -> "Job[CCT]":
         """Creates a new :class:`Job` that runs on a daily basis and adds it to the queue.
 
@@ -508,9 +549,9 @@ class JobQueue(Generic[CCT]):
         job = Job(callback=callback, data=data, name=name, chat_id=chat_id, user_id=user_id)
 
         j = self.scheduler.add_job(
-            job.run,
+            self.job_callback,
             name=name,
-            args=(self.application,),
+            args=(self, job),
             trigger="cron",
             day_of_week=",".join([self._CRON_MAPPING[d] for d in days]),
             hour=time.hour,
@@ -527,10 +568,10 @@ class JobQueue(Generic[CCT]):
         self,
         callback: JobCallback[CCT],
         job_kwargs: JSONDict,
-        data: object = None,
-        name: str = None,
-        chat_id: int = None,
-        user_id: int = None,
+        data: Optional[object] = None,
+        name: Optional[str] = None,
+        chat_id: Optional[int] = None,
+        user_id: Optional[int] = None,
     ) -> "Job[CCT]":
         """Creates a new custom defined :class:`Job`.
 
@@ -570,7 +611,7 @@ class JobQueue(Generic[CCT]):
         name = name or callback.__name__
         job = Job(callback=callback, data=data, name=name, chat_id=chat_id, user_id=user_id)
 
-        j = self.scheduler.add_job(job.run, args=(self.application,), name=name, **job_kwargs)
+        j = self.scheduler.add_job(self.job_callback, args=(self, job), name=name, **job_kwargs)
 
         job._job = j  # pylint: disable=protected-access
         return job
@@ -610,10 +651,7 @@ class JobQueue(Generic[CCT]):
         Returns:
             Tuple[:class:`Job`]: Tuple of all *scheduled* jobs.
         """
-        return tuple(
-            Job._from_aps_job(job)  # pylint: disable=protected-access
-            for job in self.scheduler.get_jobs()
-        )
+        return tuple(Job.from_aps_job(job) for job in self.scheduler.get_jobs())
 
     def get_jobs_by_name(self, name: str) -> Tuple["Job[CCT]", ...]:
         """Returns a tuple of all *pending/scheduled* jobs with the given name that are currently
@@ -642,7 +680,7 @@ class Job(Generic[CCT]):
 
         .. code-block:: bash
 
-           pip install python-telegram-bot[job-queue]
+           pip install "python-telegram-bot[job-queue]"
 
     Note:
         All attributes and instance methods of :attr:`job` are also directly available as
@@ -652,7 +690,7 @@ class Job(Generic[CCT]):
         This class should not be instantiated manually.
         Use the methods of :class:`telegram.ext.JobQueue` to schedule jobs.
 
-    .. seealso:: :wiki:`Job Queue <Extensions-%E2%80%93-JobQueue>`
+    .. seealso:: :wiki:`Job Queue <Extensions---JobQueue>`
 
     .. versionchanged:: 20.0
 
@@ -660,7 +698,7 @@ class Job(Generic[CCT]):
        * Renamed ``Job.context`` to :attr:`Job.data`.
        * Removed argument ``job``
        * To use this class, PTB must be installed via
-         ``pip install python-telegram-bot[job-queue]``.
+         ``pip install "python-telegram-bot[job-queue]"``.
 
     Args:
         callback (:term:`coroutine function`): The callback function that should be executed by the
@@ -706,15 +744,15 @@ class Job(Generic[CCT]):
     def __init__(
         self,
         callback: JobCallback[CCT],
-        data: object = None,
-        name: str = None,
-        chat_id: int = None,
-        user_id: int = None,
+        data: Optional[object] = None,
+        name: Optional[str] = None,
+        chat_id: Optional[int] = None,
+        user_id: Optional[int] = None,
     ):
         if not APS_AVAILABLE:
             raise RuntimeError(
                 "To use `Job`, PTB must be installed via `pip install "
-                "python-telegram-bot[job-queue]`."
+                '"python-telegram-bot[job-queue]"`.'
             )
 
         self.callback: JobCallback[CCT] = callback
@@ -761,7 +799,10 @@ class Job(Generic[CCT]):
             await context.refresh_data()
             await self.callback(context)
         except Exception as exc:
-            await application.create_task(application.process_error(None, exc, job=self))
+            await application.create_task(
+                application.process_error(None, exc, job=self),
+                name=f"Job:{self.id}:run:process_error",
+            )
         finally:
             # This is internal logic of application - let's keep it private for now
             application._mark_for_persistence_update(job=self)  # pylint: disable=protected-access
@@ -806,8 +847,25 @@ class Job(Generic[CCT]):
         return self.job.next_run_time
 
     @classmethod
-    def _from_aps_job(cls, job: "APSJob") -> "Job[CCT]":
-        return job.func.__self__
+    def from_aps_job(cls, aps_job: "APSJob") -> "Job[CCT]":
+        """Provides the :class:`telegram.ext.Job` that is associated with the given APScheduler
+        job.
+
+        Tip:
+            This method can be useful when using advanced APScheduler features along with
+            :class:`telegram.ext.JobQueue`.
+
+        .. versionadded:: 20.4
+
+        Args:
+            aps_job (:class:`apscheduler.job.Job`): The APScheduler job
+
+        Returns:
+            :class:`telegram.ext.Job`
+        """
+        ext_job = aps_job.args[1]
+        ext_job._job = aps_job  # pylint: disable=protected-access
+        return ext_job
 
     def __getattr__(self, item: str) -> object:
         try:
