@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,11 +19,11 @@
 """This module contains the StringRegexHandler class."""
 
 import re
-from typing import TYPE_CHECKING, Match, Optional, Pattern, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Match, Optional, Pattern, TypeVar, Union
 
 from telegram._utils.defaultvalue import DEFAULT_TRUE
-from telegram._utils.types import DVInput
-from telegram.ext._handler import BaseHandler
+from telegram._utils.types import DVType
+from telegram.ext._basehandler import BaseHandler
 from telegram.ext._utils.types import CCT, HandlerCallback
 
 if TYPE_CHECKING:
@@ -75,18 +75,18 @@ class StringRegexHandler(BaseHandler[str, CCT]):
 
     def __init__(
         self,
-        pattern: Union[str, Pattern],
+        pattern: Union[str, Pattern[str]],
         callback: HandlerCallback[str, CCT, RT],
-        block: DVInput[bool] = DEFAULT_TRUE,
+        block: DVType[bool] = DEFAULT_TRUE,
     ):
         super().__init__(callback, block=block)
 
         if isinstance(pattern, str):
             pattern = re.compile(pattern)
 
-        self.pattern = pattern
+        self.pattern: Union[str, Pattern[str]] = pattern
 
-    def check_update(self, update: object) -> Optional[Match]:
+    def check_update(self, update: object) -> Optional[Match[str]]:
         """Determines whether an update should be passed to this handler's :attr:`callback`.
 
         Args:
@@ -96,18 +96,16 @@ class StringRegexHandler(BaseHandler[str, CCT]):
             :obj:`None` | :obj:`re.match`
 
         """
-        if isinstance(update, str):
-            match = re.match(self.pattern, update)
-            if match:
-                return match
+        if isinstance(update, str) and (match := re.match(self.pattern, update)):
+            return match
         return None
 
     def collect_additional_context(
         self,
         context: CCT,
         update: str,  # skipcq: BAN-B301
-        application: "Application",  # skipcq: BAN-B301
-        check_result: Optional[Match],
+        application: "Application[Any, CCT, Any, Any, Any, Any]",  # skipcq: BAN-B301
+        check_result: Optional[Match[str]],
     ) -> None:
         """Add the result of ``re.match(pattern, update)`` to :attr:`CallbackContext.matches` as
         list with one element.
