@@ -177,7 +177,7 @@ class BaseFilter:
 
     __slots__ = ("_name", "_data_filter")
 
-    def __init__(self, name: str = None, data_filter: bool = False):
+    def __init__(self, name: Optional[str] = None, data_filter: bool = False):
         self._name = self.__class__.__name__ if name is None else name
         self._data_filter = data_filter
 
@@ -358,7 +358,10 @@ class _MergedFilter(UpdateFilter):
     __slots__ = ("base_filter", "and_filter", "or_filter")
 
     def __init__(
-        self, base_filter: BaseFilter, and_filter: BaseFilter = None, or_filter: BaseFilter = None
+        self,
+        base_filter: BaseFilter,
+        and_filter: Optional[BaseFilter] = None,
+        or_filter: Optional[BaseFilter] = None,
     ):
         super().__init__()
         self.base_filter = base_filter
@@ -526,7 +529,7 @@ class Caption(MessageFilter):
 
     __slots__ = ("strings",)
 
-    def __init__(self, strings: Union[List[str], Tuple[str, ...]] = None):
+    def __init__(self, strings: Optional[Union[List[str], Tuple[str, ...]]] = None):
         self.strings: Optional[Sequence[str]] = strings
         super().__init__(name=f"filters.Caption({strings})" if strings else "filters.CAPTION")
 
@@ -596,10 +599,8 @@ class CaptionRegex(MessageFilter):
         super().__init__(name=f"filters.CaptionRegex({self.pattern})", data_filter=True)
 
     def filter(self, message: Message) -> Optional[Dict[str, List[Match[str]]]]:
-        if message.caption:
-            match = self.pattern.search(message.caption)
-            if match:
-                return {"matches": [match]}
+        if message.caption and (match := self.pattern.search(message.caption)):
+            return {"matches": [match]}
         return {}
 
 
@@ -614,8 +615,8 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
 
     def __init__(
         self,
-        chat_id: SCT[int] = None,
-        username: SCT[str] = None,
+        chat_id: Optional[SCT[int]] = None,
+        username: Optional[SCT[str]] = None,
         allow_empty: bool = False,
     ):
         super().__init__()
@@ -956,7 +957,7 @@ CONTACT = _Contact(name="filters.CONTACT")
 class _Dice(MessageFilter):
     __slots__ = ("emoji", "values")
 
-    def __init__(self, values: SCT[int] = None, emoji: DiceEmojiEnum = None):
+    def __init__(self, values: Optional[SCT[int]] = None, emoji: Optional[DiceEmojiEnum] = None):
         super().__init__()
         self.emoji: Optional[DiceEmojiEnum] = emoji
         self.values: Optional[Collection[int]] = [values] if isinstance(values, int) else values
@@ -971,15 +972,15 @@ class _Dice(MessageFilter):
             self.name = "filters.Dice.ALL"
 
     def filter(self, message: Message) -> bool:
-        if not message.dice:  # no dice
+        if not (dice := message.dice):  # no dice
             return False
 
         if self.emoji:
-            emoji_match = message.dice.emoji == self.emoji
+            emoji_match = dice.emoji == self.emoji
             if self.values:
-                return message.dice.value in self.values and emoji_match  # emoji and value
+                return dice.value in self.values and emoji_match  # emoji and value
             return emoji_match  # emoji, no value
-        return message.dice.value in self.values if self.values else True  # no emoji, only value
+        return dice.value in self.values if self.values else True  # no emoji, only value
 
 
 class Dice(_Dice):
@@ -1594,10 +1595,8 @@ class Regex(MessageFilter):
         super().__init__(name=f"filters.Regex({self.pattern})", data_filter=True)
 
     def filter(self, message: Message) -> Optional[Dict[str, List[Match[str]]]]:
-        if message.text:
-            match = self.pattern.search(message.text)
-            if match:
-                return {"matches": [match]}
+        if message.text and (match := self.pattern.search(message.text)):
+            return {"matches": [match]}
         return {}
 
 
@@ -2186,7 +2185,7 @@ class Text(MessageFilter):
 
     __slots__ = ("strings",)
 
-    def __init__(self, strings: Union[List[str], Tuple[str, ...]] = None):
+    def __init__(self, strings: Optional[Union[List[str], Tuple[str, ...]]] = None):
         self.strings: Optional[Sequence[str]] = strings
         super().__init__(name=f"filters.Text({strings})" if strings else "filters.TEXT")
 
@@ -2316,8 +2315,8 @@ class User(_ChatUserBaseFilter):
 
     def __init__(
         self,
-        user_id: SCT[int] = None,
-        username: SCT[str] = None,
+        user_id: Optional[SCT[int]] = None,
+        username: Optional[SCT[str]] = None,
         allow_empty: bool = False,
     ):
         super().__init__(chat_id=user_id, username=username, allow_empty=allow_empty)
@@ -2452,8 +2451,8 @@ class ViaBot(_ChatUserBaseFilter):
 
     def __init__(
         self,
-        bot_id: SCT[int] = None,
-        username: SCT[str] = None,
+        bot_id: Optional[SCT[int]] = None,
+        username: Optional[SCT[str]] = None,
         allow_empty: bool = False,
     ):
         super().__init__(chat_id=bot_id, username=username, allow_empty=allow_empty)
